@@ -12,7 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-"""A pulse-level composer for Pasqal's quantum devices."""
+"""A pulse-level composer for neutral-atom quantum devices."""
 
 from pulser._version import __version__
 
