@@ -14,12 +14,10 @@
 """Valid devices for Pulser Sequence execution."""
 
 from pulser.devices._devices import (
-                                Chadoq2,
-                                )
+    Chadoq2,
+)
 
 from pulser.devices._mock_device import MockDevice
 
 # Registers which devices can be used to avoid definition of custom devices
-_valid_devices = (
-            Chadoq2,
-            )
+_valid_devices = (Chadoq2,)
